<?php
/*
 * @package Recent Forum Topics
 * @version 2.0
 * @Author: Pipke(AdemaStudios)
 * @copyright Copyright (C) 2015, Pipke
 * @All rights reserved. 
 * @This SMF modification is subject to the BSD 2-Clause License
 *
 * Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met:
 * 1. Redistributions of source code must retain the above copyright notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following disclaimer in the documentation and/or other materials provided with the distribution.
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT 
 * HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT 
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON 
 * ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

function template_rft_above()
{
	global $context, $modSettings;

	// Setup action areas
	rft_action_area();
	
	if (!empty($context['sub_template']) && (in_array($context['sub_template'], array('fatal_error', 'admin_login'))))
		return;
	
	// SP still installed or activated? And if sp_rft block is added or still exists, the block could be removed/deleted?	
	if (($modSettings['rft_sp_activated'] >= 1) && (!empty($modSettings['rft_sp_block'])))
	{
		if (isset($_REQUEST['sa']) && ($_REQUEST['sa'] == 'recentforumtopics'))  // saves a db query
			/*empty space*/;
		else
			rft_sp_info();
	}
		
	// Activated SP, we leave then... bye
	if ($modSettings['rft_sp_activated'] > 1)
		return;
	
	// Setup categories and boards in area placement mode
	if (($context['user']['is_admin']) && ($modSettings['rft_set_areas'] == 'run') && ($modSettings['rft_area_placement'] == 'select_custom'))
	{
		if (isset($_REQUEST['sa']) && ($_REQUEST['sa'] == 'recentforumtopics')) // saves a db query
			/*empty space*/;
		else
			rft_cats_boards();  
	}
	
	// Setup categories and boards in admin
	if (isset($_REQUEST['area']) && ($_REQUEST['area'] == 'manageboards')) // saves a db query
		rft_cats_boards();

	// Where are you... ill find you for sure ;)
	rft_where();
	
	
	// Did we have set this admin placement to be visible?
	if ($modSettings['rft_area_placement_where'] !== 'below_only')
	{	
		//vars
		$context['rft_template'] = 'above';
		
		//get the total above or below area placement from db
		$context['rft_db_actions'] = !empty($modSettings['rft_'. $context['rft_template'] .'_areas']) ? unserialize($modSettings['rft_'. $context['rft_template'] .'_areas']) : array();
		
		// Is the admin in area placement then show it?	
		if (($modSettings['rft_set_areas'] == 'run') && ($context['user']['is_admin']) && ($modSettings['rft_area_placement'] == 'select_custom'))
			template_rft_placement();		
		
		// Did we have set the rft_main template to be visible on all pages?
		if ($modSettings['rft_area_placement'] === 'select_all_pages')
			template_rft_main();
		else //Ok the selected custom then...
		{
			// Is the admin NOT in area placement mode, show the rft
			if (($modSettings['rft_set_areas'] == 'stop') && (in_array($context['current_action'], $context['rft_db_actions'], true)) && ($context['user']['is_admin'])) 
				template_rft_main();	
			// Are the other users allowed to view the rft?
			if (in_array($context['current_action'], $context['rft_db_actions'], true) && (!$context['user']['is_admin']))
				template_rft_main();
		}
	}
}

function template_rft_below()
{
	global $context, $modSettings;
	
	if (!empty($context['sub_template']) && (in_array($context['sub_template'], array('fatal_error', 'admin_login'))))
		return;
	
	// Activated SP, we leave then... bye
	if ($modSettings['rft_sp_activated'] > 1)
		return;
	
	// Did we maybe set this admin placement to be visible?
	if ($modSettings['rft_area_placement_where'] !== 'above_only')
	{
		//vars
		$context['rft_template'] = 'below';
		
		//get the total above or below area placement from db
		$context['rft_db_actions'] = !empty($modSettings['rft_'. $context['rft_template'] .'_areas']) ? unserialize($modSettings['rft_'. $context['rft_template'] .'_areas']) : array();
		
		// Is the admin in area placement then show it?	      
		if (($modSettings['rft_set_areas'] == 'run') && ($context['user']['is_admin']) && ($modSettings['rft_area_placement'] == 'select_custom'))
			template_rft_placement();
		
		// Did we have set the rft_main template to be visible on all pages?
		if ($modSettings['rft_area_placement'] == 'select_all_pages')
			template_rft_main();
		else //Ok the selected custom then...
		{
			// Is the admin NOT in area placement mode, show the rft
			if (($modSettings['rft_set_areas'] == 'stop') && (in_array($context['current_action'], $context['rft_db_actions'], true)) && ($context['user']['is_admin'])) 
				template_rft_main();	
			
			// Are the other users allowed to view the rft?
			if (in_array($context['current_action'], $context['rft_db_actions'], true) && (!$context['user']['is_admin']))
				template_rft_main();
		}
	}
}

function template_rft_placement()
{
	global $context, $scripturl, $settings, $txt;	
	
	// Where are we?
	rft_where();

	echo'
	<div class="information flow_hidden">
		<span>
			<a href="'.$scripturl.'?action=rftblock;area=close;', $context['session_var'], '=', $context['session_id'], '" onclick="return confirm(\'' . $txt['rft_area_placement_close'] . '\')">&nbsp;<img class="floatright" src="', $settings['images_url'], '/rft_close.gif" width="13" alt="', $txt['find_close'], '" title="', $txt['find_close'], '" /></a>
		</span>
		<span>
			<a class="help" onclick="return reqWin(this.href);" href="'.$scripturl.'?action=helpadmin;help=rft_help_placement_mode">
			<img class="floatleft" alt="Help" src="', $settings['images_url'], '/helptopics.gif"></a>', $txt['rft_area_placement_running'] ,'
		</span>
	</div>';
	
	//check the elements current action
	if (in_array($context['current_action'], $context['rft_db_actions'], true)) // action page is set in db, well then show the remove block
		echo'<a class="rftblockarealink" href="'.$scripturl.'?action=rftblock;area='. $context['rft_template'] .'remove;', $context['session_var'], '=', $context['session_id'], '"><div class="rftblockarearemove">', $txt['rft_remove_area'] ,'</div></a>&nbsp;';
	else  // action page is NOT set in db, well then show the add block
		echo'<a class="rftblockarealink" href="'.$scripturl.'?action=rftblock;area='. $context['rft_template'] .'update;', $context['session_var'], '=', $context['session_id'], '" ', empty($context['rft_unknown_actions']) ? ' onclick="return confirm(\'' . $txt['rft_area_add_empty_action'] . '\');"' : '', '><div class="rftblockareaupdate">', $txt['rft_add_area'] ,'</div></a>&nbsp;';		
}

function template_rft_main()
{
	global $context, $settings, $scripturl, $modSettings, $txt;

	// Here's where the "Recent Forum Topics" starts...
	if ($context['rft_template'] == 'below')
		echo '<br />';
	
	echo'
		<div class="cat_bar">
			<h3 class="catbg">';
			if (!empty($modSettings['rft_collapse_block']))
				echo'<img class="icon" style="float: right; margin: 10px 5px 0px 1em;" id="rft_id_upshrink_', $context['rft_template'],'" src="', $settings['images_url'], '/collapse.gif" alt="*" title="', $txt['upshrink_description'], '" style="display: none;" />';
			echo $context['forum_name'] ,' - ', $txt['rft_name'],'
			</h3>
		</div>
		<div id="rft_id_collapse_', $context['rft_template'],'"', empty($options['rft_collapse_'. $context['rft_template'].'']) ? '' : ' style="display: none;"', '>';
	
	// Rounded border
	if ($modSettings['rft_border'])
	{
		echo'<span class="clear upperframe"><span></span></span>
		<div class="roundframe"><div class="innerframe">';
	}
	else
		echo'<br />';
		
	echo' <div class="tborder topic_table">
	<table class="table_grid" cellspacing="0">
		<thead>
			<tr class="catbg">';
		
		// Are there actually any topics to show?
		if (!empty($context['rft_posts']))
		{
			echo'<th scope="col" class="first_th hidden" width="8%" colspan="2">&nbsp;</th>
			<th scope="col" class="lefttext windowbg" >', $txt['subject'], ' / ', $txt['started_by'], ' / ', $txt['rft_in_Board'], '</th>
			<th scope="col" class="hidden" width="12%">', $txt['replies'], ' / ', $txt['views'], '</th>
			<th scope="col" class="lefttext last_th" width="24%">', $txt['last_post'], '</th>';		
		}
		
		// No topics.... just say, "sorry bub".
		else 
		{
			echo'
				<th scope="col" class="first_th hidden" width="8%">&nbsp;</th>
				<th colspan="4"><strong>', $txt['msg_alert_none'], '</strong></th>
				<th scope="col" class="last_th" width="8%">&nbsp;</th>';
		}
			echo'
				</tr>
			</thead>
		<div class="pagesection" style="margin-top: -7px;">
			<div class="pagelinks floatleft">', $txt['pages'], ': ', $context['rft_page_index'], '</div>
			<div class="buttonlist floatright">
				<ul>';
				if (($context['user']['is_admin']) && (!empty($modSettings['rft_note_button'])) && (!empty($modSettings['rft_note_setting'])))
				echo'
					<li><a class="button_strip active" href="', $scripturl, '?action=admin;area=modsettings;sa=recentforumtopics#notifications"><span>', $txt['rft_notifications'],' [', $modSettings['rft_note_counter'] ,']</span></a></li>';
				if (($context['user']['is_logged']) && (!empty($modSettings['rft_menubuttons'])))
					echo'
					<li><a class="button_strip" href="', $scripturl, '?action=profile;area=showposts"><span>', $txt['rft_show_all_your_posts'] ,'</span></a></li>
					<li><a class="button_strip" href="', $scripturl, '?action=unread"><span>', rtrim($txt['unread_since_visit'],"."),'</span></a></li>
					<li><a class="button_strip" href="', $scripturl, '?action=unreadreplies"><span>', rtrim($txt['show_unread_replies'],"."), '</span></a></li>';
				echo'</ul>
			</div>
		</div>';

	// The main thingy
	foreach ($context['rft_posts'] as $post)		
	{
		// Check for posts in topics where the user has posted in. (assuming they are logged in!)
		if (!empty($modSettings['enableParticipation']) && $context['user']['is_logged'] && !empty($post['topic']))
		{
			if (in_array($post['topic'], $context['posted_topics']))	
				$post['is_own_post'] = true;
		}
		
		// Setup the icons (yeah i know scripting can better i'm lazy)
			$icon_postls = ''; // to be sure
		
		// We start with hot and real hot topics uhm autch.
		if ($post['is_hot'] && $post['is_very_hot']) 
			$icon_post1 = 'veryhot';
		elseif ($post['is_hot'])
			$icon_post1 = 'hot';
		else
			$icon_post1 = 'normal';
		
		// Poll posts...
		if (!empty($post['is_poll']))
			$icon_post2 = $icon_post1 . '_poll';	
		else
			$icon_post2 = $icon_post1 . '_post';				
		
		// Next we start with locked and sticky topics.
		if ($post['is_sticky'] && $post['is_locked']) 
			$color_class = 'stickybg locked_sticky';
		
		// Sticky topics should get a different color, too.
		elseif ($post['is_sticky']) 
		{
			$color_class = 'stickybg';
			$icon_postls = '_sticky';
		}
		
		// Locked topics get special treatment as well.
		elseif ($post['is_locked']) 
		{
			$color_class = 'lockedbg';
			$icon_postls = '_locked';
		}
		
		// Almost last, but not least: regular topics.
		else 
		{
			$color_class = 'windowbg';
			$icon_post3 = $icon_post2 . $icon_postls;				
		}
		
		// Some columns require a different shade of the color class.
			$alternate_class = $color_class . '2';			
		if ($post['is_sticky'] && $post['is_locked'])
		{
			$icon_post3 = $icon_post2 . '_locked_sticky';
			$icon_back = 'sticky_lock';
		}
		elseif ($post['is_sticky']) 
		{
			$icon_post3 = $icon_post2 . '_sticky';
			$icon_back = 'sticky';
		}
		elseif ($post['is_locked']) 
		{
			$icon_post3 = $icon_post2 . '_locked';		
			$icon_back = 'lock';
		}			
		else
		{
			$icon_post3 = $icon_post2;	
			$icon_back = false;
		}
		
		// Set the icon for posted in topics.(is_own_post)	
		if ($post['is_own_post'])
			$icon_post3 = 'my_' . $icon_post3;			
		
		// Check for solved topics.	
		if (!empty($modSettings['rft_topic_solved']) && (!empty($post['is_solved'])))
			$post['icon'] = 'topicsolved';
		
		// Check Boosted topics
		if ($modSettings['rft_boost_1'] == $post['topic'] || $modSettings['rft_boost_2'] == $post['topic'])
		{
			$rftbooster = true;
			$color_class = $color_class. ' boost';
		}
		else
			$rftbooster = false;

		// Template 	
		echo'		
			<tr>
				<td class="icon1 ', $color_class, '">
					<img src="', $settings['images_url'], '/topic/' . $icon_post3 . '.gif" alt="" />
				</td>
				<td class="icon2 ', $color_class, '">
					<img src="', $settings['images_url'], '/post/', $post['icon'], '.gif" alt="" />
				</td>				
				<td class="subject ', $alternate_class, 'rft" style="',$rftbooster ? ' background-color: #'.$modSettings['rft_color_boost'].';' : '','">';
					if (($modSettings['rft_avatar'] == 'first') || ($modSettings['rft_avatar'] == 'both'))
					{
						echo'<div style="float: left; margin-right: 6px;">';
						if (empty($post['first_poster']['id'])) //posted as guest
							echo'<img class="',$modSettings['rft_avatar_layout'] ? 'rft-avatar_round' : 'rft-avatar','" src="', $settings['images_url'], '/rft_avatar.gif" alt=""/></img>';
						elseif (!empty($post['avatar_first_poster']['href']))
							echo'<a href="' .$post['first_poster']['href']. '"><img class="',$modSettings['rft_avatar_layout'] ? 'rft-avatar_round' : 'rft-avatar','" src="', $post['avatar_first_poster']['href'],'" alt=""/></img></a>';
						else
							echo'<a href="' .$post['first_poster']['href']. '"><img class="',$modSettings['rft_avatar_layout'] ? 'rft-avatar_round' : 'rft-avatar','" src="', $settings['images_url'], '/rft_avatar.gif" alt=""/></img></a>';
						echo'</div>';
					}
					
					if (($modSettings['rft_postlinkicon'] == 'first') || ($modSettings['rft_postlinkicon'] == 'both'))
						echo'<a href="' . $scripturl . '?topic=' . $post['topic'] , '.0"><img style="float:right; padding: 3px 4px 4px 4px;" src="', $settings['images_url'], '/icons/first_post.gif" alt="', $txt['rft_first_post'], '" title="', $txt['rft_first_post'], '" /></a>';
				
					if (!empty($post['can_lock']) || !empty($post['can_mark_notify']) || !empty($post['can_sticky']) || !empty($post['can_boost']) || !empty($post['can_hide']))
					{
						$rft_margin_menu = true;
						$rft_margin = '-';
						echo'
						<ul class="dropmenu">
							<li style="float:right; padding-top:3px;">&nbsp;&nbsp;&nbsp;<img src="', $settings['images_url'], '/icons/rft_menu.gif" alt="', $txt['rft_menu'], '" /></a>
						<ul>';
					
						// Can we request notification of topics?
						if ($post['can_mark_notify'])
							echo '<li><a href="', $scripturl, '?action=notify;topic=', $post['topic'], '.', $post['jump'], '"><span><img src="', $settings['images_url'], '/icons/rft_notify.gif" alt="" /> ', $txt['notify'], '</span></a></li>'; 

						// If they *can* lock?
						if (!empty($post['can_lock']))
							echo '<li><a href="', $scripturl, '?action=lock;topic=', $post['topic'], '.', $post['jump'], ';', $context['session_var'], '=', $context['session_id'], '"><span><img src="', $settings['images_url'], '/icons/rft_lock.gif" alt="" /> ', $post['is_locked'] ? $txt['set_unlock'] : $txt['set_lock'] , '</span></a></li>';
					
						// How about... even... sticky it?!
						if (!empty($post['can_sticky']))
							echo '<li><a href="', $scripturl, '?action=sticky;topic=', $post['topic'], '.', $post['jump'], ';', $context['session_var'], '=', $context['session_id'], '"><span><img src="', $settings['images_url'], '/icons/rft_sticky.gif" alt="" /> ', $post['is_sticky'] ? $txt['set_nonsticky'] : $txt['set_sticky'] , '</span></a></li>';
					
						// You need a shot!! Boooooooost topic
						if (!empty($post['can_boost']))
						{
							if (($modSettings['rft_boost_1'] == $post['topic']) || ($modSettings['rft_boost_2'] == $post['topic'])) 
								echo '<li><a href="'.$scripturl.'?action=rftblock;area=release;topic=', $post['topic'], ';', $context['session_var'], '=', $context['session_id'], '"><span><img src="', $settings['images_url'], '/icons/rft_boost.gif" alt="" /> ', $txt['rft_un-boost_topic'] ,'</span></a></li>';						
							elseif (empty($modSettings['rft_boost_1']) || empty($modSettings['rft_boost_2']))
								echo '<li><a href="'.$scripturl.'?action=rftblock;area=boost;topic=', $post['topic'], ';', $context['session_var'], '=', $context['session_id'], '"><span><img src="', $settings['images_url'], '/icons/rft_boost.gif" alt="" /> ', $txt['rft_boost_topic'] ,'</span></a></li>';					
						}
					
						// Hide topic from table...this means not delete/remove!!
						if (!empty($post['can_hide']))
							echo '<li><a href="', $scripturl, '?action=rftblock;area=hide;topic=', $post['topic'], ';', $context['session_var'], '=', $context['session_id'], '"><span><img src="', $settings['images_url'], '/icons/rft_disable.gif" alt="" /> ', $txt['rft_disable_topic'] ,'</span></a></li>';					
						
						echo'</ul>
				</li>
				</ul>';	
				}
				else
					$rft_margin_menu = false;
				
				if (($modSettings['rft_postlinkicon'] == 'last') || ($modSettings['rft_postlinkicon'] == 'none') && $rft_margin != '-')
				{
					$rft_margin_menu = true;
					$rft_margin = '+';
				}
				
				if (!empty($icon_back))
					echo'<img style="float:right; padding: 2px 0px 4px 4px; ', $rft_margin_menu ? ' margin-right: '.$rft_margin.'8px;' : '','" src="', $settings['images_url'], '/icons/quick_'. $icon_back .'.gif" alt="', $txt['rft_first_post'], '">';
				
				// link to first...
				if (!empty($modSettings['rft_link_topics']) && ($modSettings['rft_link_topics'] == 'first'))
					echo'', $post['is_sticky'] || ($modSettings['rft_boost_1'] == $post['topic'] || $modSettings['rft_boost_2'] == $post['topic']) ? '<strong>' : '', '<span>', $post['linkfirst'],'</span>', $post['is_sticky'] || ($modSettings['rft_boost_1'] == $post['topic'] || $modSettings['rft_boost_2'] == $post['topic']) ? '</strong>' : '';
				
				//...or last topic message? 	
				if (!empty($modSettings['rft_link_topics']) && ($modSettings['rft_link_topics'] == 'last'))
					echo'', $post['is_sticky'] || ($modSettings['rft_boost_1'] == $post['topic'] || $modSettings['rft_boost_2'] == $post['topic']) ? '<strong>' : '', '<span>', $post['linklast'],'</span>', $post['is_sticky'] || ($modSettings['rft_boost_1'] == $post['topic'] || $modSettings['rft_boost_2'] == $post['topic']) ? '</strong>' : '';
										
				// Is this post new? (assuming they are logged in!)
				if ($post['new'] && $context['user']['is_logged'])
					echo' <a href="', $post['new_href'], '" /></a>';							
				
				echo'<p>', $txt['started_by'], ' ', $post['first_poster']['link'] ,' ', $post['about_last'] && $modSettings['rft_relative_date'] ? $txt['rft_about'] : '' , $modSettings['rft_relative_date'] ? '' : $txt['on'] ,' ', $modSettings['rft_relative_date'] ?  $post['time_last'] : $post['timelast'],' ', $txt['in'], ' ', $post['board']['link'], '
							<small id="pages' . $post['first_poster']['id'] . '">', $post['pages'], '</small>
							</p>
					</td>
					<td class="stats ', $color_class, '">
							', $post['replies'], ' ', $txt['replies'], '
							<br />
							', $post['views'], ' ', $txt['views'], '
					</td>
					<td class="lastpost ', $alternate_class, '" style="',$rftbooster ? ' background-color: #'.$modSettings['rft_color_boost'].';' : '','">';
					if (($modSettings['rft_avatar'] == 'last') || ($modSettings['rft_avatar'] == 'both'))
					{
					echo'<div style="float: left; margin-right: 6px;">';
					if (empty($post['poster']['id'])) //posted as guest
							echo'<img class="',$modSettings['rft_avatar_layout'] ? 'rft-avatar_round' : 'rft-avatar','" src="', $settings['images_url'], '/rft_avatar.gif" alt=""/></img>';
					elseif (!empty($post['avatar_poster']['href']))
						echo'<a href="' ,$post['poster']['href'], '"><img class="',$modSettings['rft_avatar_layout'] ? 'rft-avatar_round' : 'rft-avatar','" src="'. $post['avatar_poster']['href'].'" alt="" /></a>';
					else
						echo'<a href="' ,$post['poster']['href'], '"><img class="',$modSettings['rft_avatar_layout'] ? 'rft-avatar_round' : 'rft-avatar','" src="'. $settings['images_url']. '/rft_avatar.gif" alt="" /></a>';
					echo'</div>';
					}
					if (($modSettings['rft_postlinkicon'] == 'last') || ($modSettings['rft_postlinkicon'] == 'both'))
						echo'<a href="', $post['href'], '"><img style="padding: 3px 4px 4px 4px;" src="', $settings['images_url'], '/icons/last_post.gif" alt="', $txt['last_post'], '" title="', $txt['last_post'], '" /></a>';
					echo'', $txt['by'], ' ', $post['poster']['link'], ' <br /> ',$post['about_first'] && $modSettings['rft_relative_date'] ? $txt['rft_about'] : '' , $modSettings['rft_relative_date'] ? '' : $txt['on'] ,' ', $modSettings['rft_relative_date'] ?  $post['time_first'] : $post['timefirst'], '</span>
				
					</td>
				</tr>';
	}
	echo'	
		</table>
		</div><br />';
		
	if (!empty($modSettings['rft_postingicons']))
		echo'
		<div id="posting_icons" class="floatleft" style="margin: 0px;">
			<ul class="reset">', !empty($modSettings['enableParticipation']) && $context['user']['is_logged'] ? '
				<li class="floatleft"><img src="' . $settings['images_url'] . '/topic/my_normal_post.gif" alt="" align="middle" /> ' . $txt['participation_caption'] . '<br />' : '', '</li>
				<li class="floatleft"><img src="' . $settings['images_url'] . '/topic/normal_post.gif" alt="" align="middle" /> ' . $txt['normal_topic'] . '</li>
				<li class="floatleft"><img src="' . $settings['images_url'] . '/topic/hot_post.gif" alt="" align="middle" /> ' . $txt['rft_Hot_Topic'] . '</li>
				<li class="floatleft"><img src="' . $settings['images_url'] . '/topic/veryhot_post.gif" alt="" align="middle" /> ' . $txt['rft_Very_Hot_Topic'] . '</li>
				<li class="floatleft"><img src="' . $settings['images_url'] . '/icons/quick_lock.gif" alt="" align="middle" /> ' . $txt['locked_topic'] . '<br />' . ($modSettings['enableStickyTopics'] == '1' ? '</li>
				<li class="floatleft"><img src="' . $settings['images_url'] . '/icons/quick_sticky.gif" alt="" align="middle" /> ' . $txt['sticky_topic'] . '<br />' : '') . ($modSettings['pollMode'] == '1' ? '</li>
				<li class="floatleft"><img src="' . $settings['images_url'] . '/topic/normal_poll.gif" alt="" align="middle" /> ' . $txt['poll'] : '') . '</li>
			</ul>
		</div><span class="clear upperframe"></span>';
	
	// Rounded border
	if ($modSettings['rft_border'])
	{
		echo'</div></div>
		<span class="lowerframe"><span></span></span>';
	}
	
	echo '</div>';
	
	if ($context['rft_template'] == 'above')
		echo '<br />';

	// Recent forum topics collapse block
	echo '
	<script type="text/javascript"><!-- // --><![CDATA[
		var oInfoCenterToggle = new smc_Toggle({
			bToggleEnabled: true,
			bCurrentlyCollapsed: ', empty($options['rft_collapse_'. $context['rft_template'].'']) ? 'false' : 'true', ',
			aSwappableContainers: [
				\'rft_id_collapse_', $context['rft_template'],'\'
			],
			aSwapImages: [
				{
					sId: \'rft_id_upshrink_', $context['rft_template'],'\',
					srcExpanded: smf_images_url + \'/collapse.gif\',
					altExpanded: ', JavaScriptEscape($txt['upshrink_description']), ',
					srcCollapsed: smf_images_url + \'/expand.gif\',
					altCollapsed: ', JavaScriptEscape($txt['upshrink_description']), '
				}
			],
			oThemeOptions: {
				bUseThemeSettings: ', $context['user']['is_guest'] ? 'false' : 'true', ',
				sOptionName: \'rft_collapse_', $context['rft_template'],'\',
				sSessionVar: ', JavaScriptEscape($context['session_var']), ',
				sSessionId: ', JavaScriptEscape($context['session_id']), '
			},
			oCookieOptions: {
				bUseCookie: ', $context['user']['is_guest'] ? 'true' : 'false', ',
				sCookieName: \'rft_upshrink_', $context['rft_template'],'\'
			}
		});
	// ]]></script>';

}

?>